/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.distributedlog.exceptions;

/**
 * An exception on writing log records.
 */
public class WriteException extends DLException {

    private static final long serialVersionUID = -1836146493446072122L;

    public WriteException(String stream, String transmitError) {
        super(StatusCode.WRITE_EXCEPTION,
            "Write rejected because stream " + stream + " has encountered an error : " + transmitError);
    }

    public WriteException(String stream, String transmitError, Throwable cause) {
        super(StatusCode.WRITE_EXCEPTION,
                "Write rejected because stream " + stream + " has encountered an error : " + transmitError, cause);
    }
}
